@@ -1,7 +1,7 @@
 /*
  * GNOME Speech - Speech services for the GNOME desktop
  *
- * Copyright 2007 Sun Microsystems Inc.
+ * Copyright 2007-2008 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -267,12 +267,11 @@ espeak_speaker_new (GObject *d,
   s->driver = g_object_ref (d);
 
   /* Set the specified voice */
-  espeak_VOICE a_voice;
-  memset( &a_voice, 0, sizeof(espeak_VOICE));
-  a_voice.name = voice_spec->name;
-  a_voice.languages = NULL;
-  a_voice.gender = (voice_spec->gender == GNOME_Speech_gender_male);
-  espeak_SetVoiceByProperties(&a_voice);      
+  memset( &speaker->voice, 0, sizeof(espeak_VOICE));
+  speaker->voice.name = g_strdup(voice_spec->name);
+  speaker->voice.languages = NULL;
+  speaker->voice.gender = (voice_spec->gender == GNOME_Speech_gender_male);
+  espeak_SetVoiceByProperties(&speaker->voice);      
 
   espeak_add_parameter (speaker,
 			espeakPITCH,
@@ -290,7 +289,7 @@ espeak_speaker_new (GObject *d,
 			espeakRATE,
 			"rate",
 			80,
-			370,
+			390,
 			espeak_set_rate);  
   espeak_add_parameter (speaker,
 			espeakVOLUME,
